@@ -92,7 +92,7 @@ class FilegroupLoad(FilegroupScan):
 
         for dim, key in keyring.items_values():
             infile = np.array(self.contains[dim][key])
-            memory = np.arange(len(infile))
+            memory = np.arange(infile.size)
 
             none = np.where(np.equal(infile, None))[0]
             infile = np.delete(infile, none)
@@ -435,6 +435,15 @@ class FilegroupLoad(FilegroupScan):
 
         for cmd in commands:
             for cks in cmd:
+                # keyring argument dictates command shape
+                # help user to match `krg_inf` and `dimensions`
+                for name, input_key in keyring.items():
+                    if input_key.shape == 0:
+                        cks.infile[name].make_list_int()
+                        cks.memory[name].make_list_int()
+                    else:
+                        cks.infile[name].make_int_list()
+                        cks.memory[name].make_int_list()
                 cks.memory['var'] = self.db.idx(var)
                 cks.infile['var'] = self._get_infile_name(var)
             log.debug('Command: %s', cmd)
@@ -444,7 +453,7 @@ class FilegroupLoad(FilegroupScan):
 
             file = self.open_file(cmd.filename, mode='r+', log_lvl='info')
             try:
-                sibling_dim = self._get_order_in_file(file=file, inf_name=sibling_inf)
+                sibling_dim = self._get_order_in_file(file=file, var_name=sibling_inf)
                 kwargs.setdefault('dimensions', sibling_dim)
                 self.add_variables_to_file(file, cmd, **{var: kwargs})
             except Exception:
